@@ -65,7 +65,7 @@ if(is(input)[1] == "SpatialPolygons"){
       ID=input@polygons[[i]]@ID
     )	
   }
-  output <- SpatialPolygons(input@polygons,proj4string=CRS("+proj=utm"))
+  output <- SpatialPolygons(input@polygons,proj4string=CRS("+proj=eqc +lat_ts=0 +lat_0=0 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"))
 
   
 #-------------------------------------------------------------------------------
